Thread-safe C++ port of minqa::bobyqa(): minimizes a function of
many variables subject to box constraints by a trust region method that
forms quadratic models by interpolation, using M. J. D. Powell's BOBYQA
algorithm. Arguments, defaults, and return value are those of
minqa::bobyqa(); see its documentation for details.
Usage
bobyqa(par, fn, lower = -Inf, upper = Inf, control = list(), ...)Source
M. J. D. Powell's original Fortran 77 BOBYQA code, archived at https://github.com/libprima/prima/tree/main/fortran/original/bobyqa; R interface following the minqa package.
Arguments
- par
numeric vector of starting parameters.
- fn
function to be minimized; its first argument must be the parameter vector and it must return a scalar numeric value.
- lower, upper
numeric vectors of lower and upper bounds (recycled when of length 1).
- control
a list of control settings:
npt,rhobeg,rhoend,iprint,maxfun,obstopandforce.start, as inminqa::bobyqa().- ...
further arguments passed to
fn.